@@ -1,6 +1,6 @@
 # check_perl_modules.pl - This script checks installed and required Perl modules
 # It also does the required installations
-# RCS Identication ; $Revision: 1.14.2.2 $ ; $Date: 2003/04/08 13:37:29 $ 
+# RCS Identication ; $Revision: 1.27.2.1 $ ; $Date: 2004/04/19 13:07:29 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -25,14 +25,14 @@ use CPAN;
 ## assume version = 1.0 if not specified.
 ## 
 %versions = ('perl' => '5.005',
-             'Net::LDAP' =>, '0.10', 
+             'Net::LDAP' =>, '0.27', 
 	     'perl-ldap' => '0.10',
-	     'Mail::Internet' => '1.32', 
+	     'Mail::Internet' => '1.51', 
 	     'DBI' => '1.06',
 	     'DBD::Pg' => '0.90',
 	     'DBD::Sybase' => '0.90',
 	     'DBD::mysql' => '2.0407',
-	     'FCGI' => '0.48',
+	     'FCGI' => '0.67',
 	     'MIME::Tools' => '5.209',
 	     'File::Spec' => '0.8',
              'Crypt::CipherSaber' => '0.50',
@@ -41,7 +41,10 @@ use CPAN;
 	     'DB_File' => '1.75',
 	     'IO::Socket::SSL' => '0.90',
 	     'Net::SSLeay' => '1.16',
-	     'Bundle::LWP' => '1.09');
+	     'Archive::Zip' => '1.05',
+	     'Bundle::LWP' => '1.09',
+	     'SOAP::Lite' => '0.60'
+	     );
 
 ### key:left "module" used by SYMPA, 
 ### right CPAN module.		     
@@ -52,7 +55,9 @@ use CPAN;
 	     'MIME::Tools' => 'MIME-tools',
 	     'MIME::Base64' => 'MIME-Base64',
 	     'CGI' => 'CGI',
-	     'File::Spec' => 'File-Spec');
+	     'File::Spec' => 'File-Spec',
+	     'Archive::Zip' => 'Archive-Zip',
+	     );
 
 %opt_CPAN = ('DBI' => 'DBI',
 	     'DBD::mysql' => 'Msql-Mysql-modules',
@@ -66,21 +71,24 @@ use CPAN;
 	     'Net::SMTP' => 'libnet',
 	     'IO::Socket::SSL' => 'IO-Socket-SSL',
 	     'Net::SSLeay' => 'NET-SSLeay',
-	     'Bundle::LWP' => 'LWP');
+	     'Bundle::LWP' => 'LWP',
+	     'SOAP::Lite' => 'SOAP-Lite');
 
 %opt_features = ('DBI' => 'a generic Database Driver, required by Sympa to access Subscriber information and User preferences. An additional Database Driver is required for each database type you wish to connect to.',
-		 'DBD::mysql' => 'Mysql database driver, required if you connect to a Mysql database.',
+		 'DBD::mysql' => 'Mysql database driver, required if you connect to a Mysql database.\nYou first need to install the Mysql server and have it started before installing the Perl DBD module.',
 		 'DBD::Pg' => 'PostgreSQL database driver, required if you connect to a PostgreSQL database.',
 		 'DBD::Oracle' => 'Oracle database driver, required if you connect to a Oracle database.',
 		 'DBD::Sybase' => 'Sybase database driver, required if you connect to a Sybase database.',
 		 'Net::LDAP' =>   'required to query LDAP directories. Sympa can do LDAP-based authentication ; it can also build mailing lists with LDAP-extracted members.',
 		 'CGI::Fast' => 'WWSympa, Sympa\'s web interface can run as a FastCGI (ie: a persistent CGI). If you install this module, you will also need to install the associated mod_fastcgi for Apache.',
 		 'Crypt::CipherSaber' => 'this module provides reversible encryption of user passwords in the database.',
+		 'Archive::Zip ' => 'this module provides zip/unzip for archive and shared document download/upload',
 		 'FCGI' => 'WSympa, Sympa\'s web interface can run as a FastCGI (ie: a persistent CGI). If you install this module, you will also need to install the associated mod_fastcgi for Apache.',
 		 'Net::SMTP' => 'this is required if you set \'list_check_smtp\' sympa.conf parameter, used to check existing aliases before mailing list creation.',
-		 'IO::Socket::SSL' => 'required by the \'include_remote_sympa_list\' feature that includes members of a list on a remote server, using X509 authentication',
+		 'IO::Socket::SSL' => 'required by CAS (single sign-on) and the \'include_remote_sympa_list\' feature that includes members of a list on a remote server, using X509 authentication',
 		 'Net::SSLeay' => 'required by the \'include_remote_sympa_list\' feature that includes members of a list on a remote server, using X509 authentication',
-		 'Bundle::LWP' => 'required by the \'include_remote_sympa_list\' feature that includes members of a list on a remote server, using X509 authentication');
+		 'Bundle::LWP' => 'required by the \'include_remote_sympa_list\' feature that includes members of a list on a remote server, using X509 authentication',
+		 'SOAP::Lite' => 'required if you want to run the Sympa SOAP server that provides ML services via a "web service"');
 
 ### main:
 print "******* Check perl for SYMPA ********\n";
@@ -139,7 +147,7 @@ sub check_modules {
 	    ### doesn't return 1;
 	    print "$mod doesn't return 1 (check it).\n";
 	} else {
-	    print "$status";
+	    print "$status\n";
 	}
     }
 }
@@ -155,6 +163,10 @@ sub install_module {
 	print "Setting FTP Passive mode\n";
     }
 
+    ## This is required on RedHat 9 for DBD::mysql installation
+    my $lang = $ENV{'LANG'};
+    $ENV{'LANG'} = 'C' if ($ENV{'LANG'} eq 'en_US.UTF-8');
+
     unless ($> == 0) {
 	print "\#\# You need root privileges to install $module module. \#\#\n";
 	print "\#\# Press the Enter key to continue checking modules. \#\#\n";
@@ -169,6 +181,10 @@ sub install_module {
     next unless ($answer =~ /^y$/i);
   CPAN::Shell->conf('inactivity_timeout', 4);
     CPAN::Shell->install($module);
+
+    ## Restore lang
+    $ENV{'LANG'} = $lang if (defined $lang);
+
 }
 
 ###--------------------------
