@@ -1,5 +1,5 @@
 # Command.pm - this module does the mail commands processing
-# RCS Identication ; $Revision: 1.87.2.1 $ ; $Date: 2004/05/14 12:11:18 $ 
+# RCS Identication ; $Revision: 1.87.2.2 $ ; $Date: 2004/11/22 09:59:19 $ 
 
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -815,7 +815,8 @@ sub signoff {
     if ($which eq '*') {
 	my $success ;
 	foreach $l ( List::get_which ($email,$robot,'member') ){
-            $success ||= &signoff($l,$email);
+	    my $result = &signoff("$l $email", $robot);
+            $success ||= $result;
 	}
 	return ($success);
     }
@@ -862,7 +863,7 @@ sub signoff {
 	}else {
 	    push @msg::report, sprintf Msg(6, 80, "You are not allowed to perform %s %s in list %s.\n"),'sig',$which,$email;
 	}
-	do_log('info', 'DEL %s %s from %s refused (not allowed)', $which, $email, $sender);
+	do_log('info', 'SIG %s %s from %s refused (not allowed)', $which, $email, $sender);
 	return 'not_allowed';
     }
     if ($action =~ /request_auth\s*\(\s*\[\s*(email|sender)\s*\]\s*\)/i) {
