@@ -1,5 +1,5 @@
 # Ldap.pm - This module includes most LDAP-related functions
-# RCS Identication ; $Revision: 1.6.2.1 $ ; $Date: 2003/03/13 08:45:49 $ 
+# RCS Identication ; $Revision: 1.9 $ ; $Date: 2004/03/03 15:06:02 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -118,10 +118,11 @@ sub export_list{
 	push(@editor_names,$element->{'gecos'}) if(defined $element->{'gecos'});
     }
 
-    unless (require Net::LDAP) {
+    unless (eval "require Net::LDAP") {
        &Log::do_log ('err',"Unable to use LDAP library, Net::LDAP required, install perl-ldap (CPAN) first");
        return undef;
     }
+    require Net::LDAP;
     
     ##Connexion
     my $ldap = Net::LDAP->new($Conf{'ldap_export'}{$directory}{'host'});
@@ -198,11 +199,12 @@ sub delete_list{
 
     my $already_binded = 1;
 
-    unless (require Net::LDAP) {
+    unless (eval "require Net::LDAP") {
         &Log::do_log ('err',"Unable to use LDAP library, Net::LDAP required, install perl-ldap (CPAN) first");
         return undef;
     }
-    
+    require Net::LDAP;
+
     ## We may used delete_list independently OR from export_list()
     unless (defined $ldap) {
       $already_binded = 0;
@@ -259,10 +261,11 @@ sub get_exported_lists{
 
     my %lists;
     
-    unless (require Net::LDAP) {
+    unless (eval "require Net::LDAP") {
 	&Log::do_log ('err',"Unable to use LDAP library, Net::LDAP required, install perl-ldap (CPAN) first");
         return undef;
     }
+    require Net::LDAP;
     
     my $ldap = Net::LDAP->new($Conf{'ldap_export'}{$directory}{'host'}, timeout => $Conf{'ldap_export'}{$directory}{'connection_timeout'});
     unless ($ldap) {
@@ -309,10 +312,11 @@ sub get_dn_anonymous{
     $datas->{'timeout'} = 20 unless($datas->{'timeout'});
     $datas->{'scope'} = 'sub' unless($datas->{'scope'});
     
-    unless (require Net::LDAP) {
+    unless (eval "require Net::LDAP") {
         &Log::do_log ('err',"Unable to use LDAP library, Net::LDAP required, install perl-ldap (CPAN) first");
         return undef;
     }
+    require Net::LDAP;
 
     ##New
     my $ldap = Net::LDAP->new($datas->{'host'},timeout => $datas->{'timeout'});
