@@ -1,7 +1,7 @@
 #! --PERL--
 
 # Log.pm - This module includes all Logging-related functions
-# RCS Identication ; $Revision: 1.11 $ ; $Date: 2002/02/15 11:27:51 $ 
+# RCS Identication ; $Revision: 1.15 $ ; $Date: 2004/02/20 09:53:02 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -39,10 +39,14 @@ sub fatal_err {
     
     syslog('err', $m, @_);
     syslog('err', "Exiting.");
-#   if ($main::options{'debug'} || $main::options{'foreground'}) {
     $m =~ s/%m/$errno/g;
+
+    my $full_msg = sprintf $m,@_;
+
+    ## Notify listmaster
+    &List::send_notify_to_listmaster('sympa_died', $Conf{'domain'}, $m);
+
     printf STDERR "$m\n", @_;
-#   }
     exit(1);   
 }
 
@@ -69,9 +73,12 @@ sub do_log {
 	&do_connect();
 	    syslog($fac, $m, @_);
     }
-    if ($main::options{'foreground'})  {
-	$m =~ s/%m/$errno/g;
-	printf STDERR "$m\n", @_;
+    if ($main::options{'foreground'}) {
+	if (!$main::options{'batch'} 
+	    || ($main::options{'batch'} && $fac eq 'err')) {
+	    $m =~ s/%m/$errno/g;
+	    printf STDERR "$m\n", @_;
+	}
     }    
 }
 
