@@ -1,5 +1,5 @@
 /* aliaswrapper.c - This program, distributed with Sympa, is a wrapper to 'newaliases'
-  RCS Identication ; $Revision: 1.4 $ ; $Date: 2001/12/04 13:19:03 $ 
+  RCS Identication ; $Revision: 1.7 $ ; $Date: 2002/04/09 08:41:06 $ 
  
   Sympa - SYsteme de Multi-Postage Automatique
   Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -24,8 +24,18 @@
 
 int main(int argc, char *argv[])
 {
+	extern char **environ;
+	char *arg[3];
+
+	environ[0] = NULL;
+	arg[0] = NEWALIASES;
+	arg[1] = NEWALIASES_ARG;
+	arg[2] = NULL;
+	if (*arg[1] == '\0') {
+	  arg[1] = NULL;
+	}
 	setuid(0);
-	execle(NEWALIASES, NEWALIASES, NEWALIASES_ARG, NULL);
+	execv(arg[0], arg);
 	perror("Exec of "NEWALIASES NEWALIASES_ARG" failed!");
 	exit(1);
 }
