@@ -3,7 +3,7 @@
 # p12topem.pl - This script installs a List X509 cert and
 # the associated private key in list directory
 # Input is PKCS#12 file
-# RCS Identication ; $Revision: 1.5 $ ; $Date: 2003/04/02 15:16:12 $ 
+# RCS Identication ; $Revision: 1.5.4.1 $ ; $Date: 2004/06/30 15:42:02 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -37,6 +37,17 @@ use List;
 unless (&Conf::load($sympa_conf_file)) {
     die 'config_error';
 }
+
+## Probe Db if defined
+if ($Conf{'db_name'} and $Conf{'db_type'}) {
+    unless ($List::use_db = &List::probe_db()) {
+	&die('Database %s defined in sympa.conf has not the right structure or is unreachable. If you don\'t use any database, comment db_xxx parameters in sympa.conf', $Conf{'db_name'});
+    }
+}
+
+## Apply defaults to %List::pinfo
+&List::_apply_defaults();
+
 my $openssl = $Conf{'openssl'};
 my $home_sympa = $Conf{'home'};
 my $outpass = $Conf{'key_passwd'};
@@ -46,6 +57,7 @@ my $etc_dir = $Conf{'etc'};
 my %options;
 &GetOptions(\%main::options, 'pkcs12=s','listname=s', 'robot=s', 'help|h');
 
+$main::options{'foreground'} = 1;
 my $listname = $main::options{'listname'};
 my $robot = $main::options{'robot'};
 my $p12input = $main::options{'pkcs12'};
@@ -79,11 +91,11 @@ if (($main::options{'help'} ne '') ||
     }
 
     if (-r "$cert") {
-	printf "$cert certificat allready exist\n";
+	printf "$cert certificat already exist\n";
 	die;
     }
     if (-r "$privatekey") {
-	printf "$privatekey allready exist\n";
+	printf "$privatekey already exist\n";
 	die;
     }
     
