@@ -2,7 +2,7 @@
 
 # sympa.pl - This script is the main one ; it runs as a daemon and does
 # the messages/commands processing
-# RCS Identication ; $Revision: 1.104.2.5 $ ; $Date: 2003/04/29 09:50:44 $ 
+# RCS Identication ; $Revision: 1.128.2.2 $ ; $Date: 2004/04/19 13:23:52 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -39,7 +39,6 @@ use Version;
 use smtp;
 use MIME::QuotedPrint;
 use List;
-use Ldap;
 use Message;
 
 require 'tools.pl';
@@ -63,27 +62,25 @@ my $digestsleep = 5;
 ## Init random engine
 srand (time());
 
-my $version_string = "Sympa version is $Version
-
-Try $0 --help for further information about Sympa
-";
+my $version_string = "Sympa version is $Version\n";
 
 my $usage_string = "Usage:
    $0 [OPTIONS]
 
 Options:
-   -d, --debug         : sets Sympa in debug mode 
-   -f, --config=FILE   : uses an alternative configuration file
-   --import=list       : import subscribers (read from STDIN)
-   -k, --keepcopy=dir  : keep a copy of incoming message
-   -l, --lang=LANG     : use a language catalog for Sympa
-   -m, --mail          : log calls to sendmail
-   --dump=list|ALL     : dumps subscribers 
-   --lowercase         : lowercase email addresses in database
-   --log_level=LEVEL   : sets Sympa log level
+   -d, --debug                           : sets Sympa in debug mode 
+   -f, --config=FILE                     : uses an alternative configuration file
+   --import=list                         : import subscribers (read from STDIN)
+   -k, --keepcopy=dir                    : keep a copy of incoming message
+   -l, --lang=LANG                       : use a language catalog for Sympa
+   -m, --mail                            : log calls to sendmail
+   --dump=list|ALL                       : dumps subscribers 
+   --lowercase                           : lowercase email addresses in database
+   --close_list=LISTNAME[\@ROBOT]         : close a list
+   --log_level=LEVEL                     : sets Sympa log level
 
-   -h, --help          : print this help
-   -v, --version       : print version number
+   -h, --help                            : print this help
+   -v, --version                         : print version number
 
 Sympa is a mailinglists manager and comes with a complete (user and admin)
 web interface. Sympa  can be linked to an LDAP directory or an RDBMS to 
@@ -94,7 +91,8 @@ encryption.
 ## Check --dump option
 my %options;
 &GetOptions(\%main::options, 'dump=s', 'debug|d', ,'log_level=s','foreground', 'config|f=s', 
-	    'lang|l=s', 'mail|m', 'keepcopy|k=s', 'help', 'version', 'import=s','make_alias_file','lowercase');
+	    'lang|l=s', 'mail|m', 'keepcopy|k=s', 'help', 'version', 'import=s','make_alias_file','lowercase',
+	    'close_list=s');
 
 
 if ($main::options{'debug'}) {
@@ -107,7 +105,17 @@ $main::options{'foreground'} = 1 if ($main::options{'debug'} ||
 				     $main::options{'help'} || 
 				     $main::options{'make_alias_file'} || 
 				     $main::options{'lowercase'} || 
-				     $main::options{'dump'});
+				     $main::options{'dump'} ||
+				     $main::options{'close_list'});
+
+## Batch mode, ie NOT daemon
+ $main::options{'batch'} = 1 if ($main::options{'dump'} || 
+				 $main::options{'help'} ||
+				 $main::options{'version'} || 
+				 $main::options{'import'} || 
+				 $main::options{'make_alias_file'} ||
+				 $main::options{'lowercase'} ||
+				 $main::options{'close_list'});
 
 $log_level = $main::options{'log_level'} if ($main::options{'log_level'}); 
 
@@ -123,8 +131,7 @@ while ($signal ne 'term') { #as long as a SIGTERM is not received }
 my $config_file = $main::options{'config'} || '--CONFIG--';
 ## Load configuration file
 unless (Conf::load($config_file)) {
-   print Msg(1, 1, "Configuration file $config_file has errors.\n");
-   exit(1);
+   &fatal_err("Configuration file $config_file has errors.");
 }
 
 ## Open the syslog and say we're read out stuff.
@@ -153,7 +160,6 @@ if ($Conf{'db_name'} and $Conf{'db_type'}) {
 
 if (&tools::cookie_changed($Conf{'cookie'})) {
      &fatal_err("sympa.conf/cookie parameter has changed. You may have severe inconsitencies into password storage. Restore previous cookie or write some tool to re-encrypt password in database and check spools contents (look at $Conf{'etc'}/cookies.history file)");
-    exit;
 }
 
 ## Set locale configuration
@@ -188,15 +194,13 @@ if ($signal ne 'hup' ) {
 	open(STDOUT, ">> /dev/null");
 	setpgrp(0, 0);
 	if ((my $child_pid = fork) != 0) {
-	    do_log('debug', "Starting server, pid $_");
+	    do_log('debug', "Starting server, pid $child_pid");
 
 	    exit(0);
 	}
     }
     
-    unless ($main::options{'dump'} || $main::options{'help'} ||
-	    $main::options{'version'} || $main::options{'import'} || $main::options{'make_alias_file'} ||
-	    $main::options{'lowercase'} ) {
+    unless ($main::options{'batch'} ) {
 	## Create and write the pidfile
 	&tools::write_pid($Conf{'pidfile'}, $$);
     }	
@@ -207,15 +211,17 @@ if ($signal ne 'hup' ) {
     $( = $) = (getgrnam('--GROUP--'))[2];
     $< = $> = (getpwnam('--USER--'))[2];
 
+    ## Required on FreeBSD to change ALL IDs(effective UID + real UID + saved UID)
+    &POSIX::setuid((getpwnam('--USER--'))[2]);
+    &POSIX::setgid((getgrnam('--GROUP--'))[2]);
+
     # Sets the UMASK
     umask(oct($Conf{'umask'}));
 
  ## Most initializations have now been done.
     do_log('notice', "Sympa $Version started");
-    printf "Sympa $Version started\n";
 }else{
     do_log('notice', "Sympa $Version reload config");
-    printf "Sympa $Version reload config\n";
     $signal = '0';
 }
 
@@ -235,7 +241,10 @@ if ($main::options{'dump'}) {
 	@listnames = ($main::options{'dump'});
     }
 
-    &List::dump(@listnames);
+    unless (&List::dump(@listnames)) {
+	printf STDERR "Could not dump list(s) %s\n", join(',',@listnames);
+	exit -1;
+    }
 
     exit 0;
 }elsif ($main::options{'help'}) {
@@ -284,8 +293,6 @@ if ($main::options{'dump'}) {
 	%{$u} = %{$defaults};
 	$u->{'email'} = $email;
 	$u->{'gecos'} = $gecos;
-	$u->{'date'} = $u->{'update_date'} = time;
-	$u->{'subscribed'} = 1 if ($list->{'admin'}{'user_data_source'} eq 'include2');
 
 	unless ($list->add_user($u)) {
 	    printf STDERR "\nCould not add %s\n", $email;
@@ -317,6 +324,24 @@ if ($main::options{'dump'}) {
 
     printf STDERR "Total lowercased rows: %d\n", $total;
 
+    exit 0;
+}elsif ($main::options{'close_list'}) {
+
+    my ($listname, $robotname) = split /\@/, $main::options{'close_list'};
+    my $list = new List ($listname, $robotname);
+
+    unless (defined $list) {
+	print STDERR "Incorrect list name $main::options{'close_list'}\n";
+	exit 1;
+    }
+
+    unless ($list->close()) {
+	print STDERR "Could not close list $main::options{'close_list'}\n";
+	exit 1;	
+    }
+
+    printf STDOUT "List %s has been closed, aliases have been removed\n", $list->{'name'};
+    
     exit 0;
 }
 
@@ -492,15 +517,13 @@ while (!$signal) {
 
 	if (-d $bad_dir) {
 	    unless (rename("$Conf{'queue'}/$filename", "$bad_dir/$filename")){
-		do_log('err', "Exiting, unable to rename bad file %s to %s (check directory permission)", $filename, "$bad_dir/$filename");
-		exit;
+		&fatal_err("Exiting, unable to rename bad file $filename to $bad_dir/$filename (check directory permission)");
 	    }
 	    do_log('notice', "Moving bad file %s to bad/", $filename);
 	}else{
 	    do_log('notice', "Missing directory '%s'", $bad_dir);
 	    unless (rename("$Conf{'queue'}/$filename", "$Conf{'queue'}/BAD-$filename")) {
-		do_log('err', "Exiting, unable to rename bad file %s to BAD-%s", $filename, $filename);
-		exit;		
+		&fatal_err("Exiting, unable to rename bad file $filename to BAD-$filename");
 	    }
 	    do_log('notice', "Renaming bad file %s to BAD-%s", $filename, $filename);
 	}
@@ -561,9 +584,9 @@ sub DoFile {
 	return undef;
     }
     
-    open TMP, ">/tmp/dump";
-    $message->dump(\*TMP);
-    close TMP;
+#    open TMP, ">/tmp/dump";
+#    $message->dump(\*TMP);
+#    close TMP;
 
     my $msg = $message->{'msg'};
     my $hdr = $msg->head;
@@ -660,15 +683,6 @@ sub DoFile {
     ## encrypted message
     if ($message->{'smime_crypted'}) {
 	$is_crypted = 'smime_crypted';
-	$file = '_ALTERED_';
-	($msg, $file) = ($message->{'decrypted_msg'}, $message->{'decrypted_msg_as_string'});
-	unless (defined($msg)) {
-	    do_log('debug','unable to decrypt message');
-	    ## xxxxx traitement d'erreur ?
-	    return undef;
-	};
-	$hdr = $msg->head;
-	do_log('debug2', "message successfully decrypted");
     }else {
 	$is_crypted = 'not_crypted';
     }
@@ -681,6 +695,18 @@ sub DoFile {
 	undef $is_signed;
     }
 
+   #  anti-virus
+    if (my $rc= &tools::virus_infected($message->{'msg'}, $message->{'filename'})) {
+	if ($Conf{'antivirus_notify'} eq 'sender') {
+	    #printf "do message, virus= $rc \n";
+	    &List::send_global_file('your_infected_msg', $sender, $robot, {'virus_name' => $rc,
+									   'recipient' => $name.'@'.$host,
+									   'lang' => $Language::default_lang});
+	}
+	&do_log('notice', "Message for %s\@%s from %s ignored, virus %s found", $name, $host, $sender, $rc);
+	return undef;
+    }
+   #  
 
     if ($rcpt =~ /^listmaster(\@(\S+))?$/) {
 	$status = &DoForward('sympa', 'listmaster', $robot, $msg, $file, $sender);
@@ -691,12 +717,9 @@ sub DoFile {
 	$status = &DoCommand($rcpt, $robot, $msg, $file);
 	
 	## forward mails to <list>-request <list>-owner etc
-#    }elsif ($rcpt =~ /^(\S+)-(request|owner|editor)(\@(\S+))?$/o) {
     }elsif ($type =~ /^(request|owner|editor)$/o) {
-#	my ($name, $function) = ($1, $2);
 	
 	## Simulate Smartlist behaviour with command in subject
-         ## 
 	if (($type eq 'request') and ($subject_field =~ /^\s*(subscribe|unsubscribe)(\s*$listname)?\s*$/i) ) {
 	    my $command = $1;
 	    
@@ -723,7 +746,7 @@ sub DoFile {
 	    ## Notify listmaster of first rejection
 	    if ($loop_info{$sender}{'count'} == $Conf{'loop_command_max'}) {
 		## Notify listmaster
-		&List::send_notify_to_listmaster('loop_command', $robot, $file);
+		&List::send_notify_to_listmaster('loop_command', $Conf{'domain'}, $file);
 	    }
 	    
 	    ## Too many reports sent => message skipped !!
@@ -787,6 +810,7 @@ sub DoSendMessage {
 
     $hdr->delete('X-Sympa-Checksum');
     $hdr->delete('X-Sympa-To');
+    $hdr->delete('X-Sympa-From');
     
     ## Multiple recepients
     my @rcpts = split /,/,$rcpt;
@@ -865,33 +889,33 @@ sub DoForward {
     my $rc;
     my $msg_copy = $msg->dup;
 
-    if ($rc = &tools::virus_infected($msg_copy, $file)) {
-	if ($Conf{'antivirus_notify'} eq 'sender') {
-	    if ($list) {
-		$list->send_file('your_infected_msg', $sender, $robot, 
-				 {'virus_name' => $rc,
-				  'recipient' => $recepient.'@'.$host,
-				  'lang' => $list->{'admin'}{'lang'}});
-	    }
-	    else {
-		my %context;
-		$context{'virus_name'} = $rc ;
-		$context{'recipient'} = $recepient.'@'.$host;
-		$context{'lang'} = &Conf::get_robot_conf($robot, 'lang');
-		&List::send_global_file('your_infected_msg', $sender, $robot, \%context );
-	    }    
-	}
-	&do_log('notice', "Message for %s\@%s from %s ignored, virus %s found", $recepient, $host, $sender, $rc);
-
-	return undef;
-    }else{
+#    if ($rc = &tools::virus_infected($msg_copy, $file)) {
+#	if ($Conf{'antivirus_notify'} eq 'sender') {
+#	    if ($list) {
+#		$list->send_file('your_infected_msg', $sender, $robot, 
+#				 {'virus_name' => $rc,
+#				  'recipient' => $recepient.'@'.$host,
+#				  'lang' => $list->{'admin'}{'lang'}});
+#	    }
+#	    else {
+#		my %context;
+#		$context{'virus_name'} = $rc ;
+#		$context{'recipient'} = $recepient.'@'.$host;
+#		$context{'lang'} = &Conf::get_robot_conf($robot, 'lang');
+#		&List::send_global_file('your_infected_msg', $sender, $robot, \%context );
+#	    }    
+#	}
+#	&do_log('notice', "Message for %s\@%s from %s ignored, virus %s found", $recepient, $host, $sender, $rc);
+#
+#	return undef;
+#    }else{
  
 	*SIZ = smtp::smtpto(&Conf::get_robot_conf($robot, 'request'), \@rcpt);
 	$msg->print(\*SIZ);
 	close(SIZ);
 	
 	do_log('info',"Message for %s forwarded", $recepient);
-    }
+#   }
     return 1;
 }
 
@@ -899,15 +923,12 @@ sub DoForward {
 ## Handles a message sent to a list.
 sub DoMessage{
     my($which, $message, $robot) = @_;
-    my ($msg, $file, $bytes) = ($message->{'msg'}, $message->{'filename'}, $message->{'size'});
-    my $encrypt;
-    $encrypt = 'smime_crypted' if ($message->{'smime_crypted'});
-    &do_log('debug', 'DoMessage(%s, %s, %s, msg from %s, %s, %s,%s)', $which, $msg, $robot, $msg->head->get('From'), $bytes, $file, $encrypt);
+    &do_log('debug', 'DoMessage(%s, %s, %s, msg from %s, %s, %s,%s)', $which, $message->{'msg'}, $robot, $message->{'sender'}, $message->{'size'}, $message->{'msg_as_string'}, $message->{'smime_crypted'});
     
     ## List and host.
     my($listname, $host) = split(/[@\s]+/, $which);
 
-    my $hdr = $msg->head;
+    my $hdr = $message->{'msg'}->head;
     
     my $from_field = $hdr->get('From');
     my $messageid = $hdr->get('Message-Id');
@@ -931,7 +952,7 @@ sub DoMessage{
 	return undef;
     }
     
-    my ($name, $host) = ($list->{'name'}, $list->{'admin'}{'host'});
+    ($listname, $host) = ($list->{'name'}, $list->{'admin'}{'host'});
 
     my $start_time = time;
     
@@ -939,7 +960,7 @@ sub DoMessage{
 
     ## Now check if the sender is an authorized address.
 
-    do_log('info', "Processing message for %s with priority %s, %s", $name,$list->{'admin'}{'priority'}, $messageid );
+    do_log('info', "Processing message for %s with priority %s, %s", $listname,$list->{'admin'}{'priority'}, $messageid );
     
     my $conf_email = &Conf::get_robot_conf($robot, 'sympa');
     if ($sender =~ /^(mailer-daemon|sympa|listserv|majordomo|smartlist|mailman|$conf_email)(\@|$)/mio) {
@@ -955,7 +976,7 @@ sub DoMessage{
     # Reject messages with commands
     if ($Conf{'misaddressed_commands'} =~ /reject/i) {
 	## Check the message for commands and catch them.
-	if (tools::checkcommand($msg, $sender, $robot)) {
+	if (tools::checkcommand($message->{'msg'}, $sender, $robot)) {
 	    &do_log('notice', 'Found command in message, ignoring message');
 	    
 	    return undef;
@@ -970,39 +991,39 @@ sub DoMessage{
 
     ## Check if the message is a return receipt
     if ($hdr->get('multipart/report')) {
-	do_log('notice', 'Message for %s from %s ignored because it is a report', $name, $sender);
+	do_log('notice', 'Message for %s from %s ignored because it is a report', $listname, $sender);
 	return undef;
     }
     
     ## Check if the message is too large
     my $max_size = $list->get_max_size() || $Conf{'max_size'};
-    if ($max_size && $bytes > $max_size) {
-	do_log('notice', 'Message for %s from %s too large (%d > %d)', $name, $sender, $bytes, $max_size);
+    if ($max_size && $message->{'size'} > $max_size) {
+	do_log('notice', 'Message for %s from %s rejected because too large (%d > %d)', $listname, $sender, $message->{'size'}, $max_size);
 	*SIZ  = smtp::smtpto(&Conf::get_robot_conf($robot, 'request'), \$sender);
 	print SIZ "From: " . sprintf (Msg(12, 4, 'SYMPA <%s>'), &Conf::get_robot_conf($robot, 'request')) . "\n";
 	printf SIZ "To: %s\n", $sender;
-	printf SIZ "Subject: " . Msg(4, 11, "Your message for list %s has been rejected") . "\n", $name;
+	printf SIZ "Subject: " . Msg(4, 11, "Your message for list %s has been rejected") . "\n", $listname;
 	printf SIZ "MIME-Version: %s\n", Msg(12, 1, '1.0');
 	printf SIZ "Content-Type: text/plain; charset=%s\n", Msg(12, 2, 'us-ascii');
 	printf SIZ "Content-Transfer-Encoding: %s\n\n", Msg(12, 3, '7bit');
 	print SIZ Msg(4, 12, $msg::msg_too_large);
-	$msg->print(\*SIZ);
+	$message->{'msg'}->print(\*SIZ);
 	close(SIZ);
 	return undef;
     }
     
     my $rc;
    
-    if ($rc= &tools::virus_infected($msg, $file)) {
-	if ($Conf{'antivirus_notify'} eq 'sender') {
-	    #printf "do message, virus= $rc \n";
-	    $list->send_file('your_infected_msg', $sender, $robot, {'virus_name' => $rc,
-								    'recipient' => $name.'@'.$host,
-								    'lang' => $list->{'admin'}{'lang'}});
-	}
-	&do_log('notice', "Message for %s\@%s from %s ignored, virus %s found", $name, $host, $sender, $rc);
-	return undef;
-    }
+#    if ($rc= &tools::virus_infected($message->{'msg'}, $message->{'filename'})) {
+#	if ($Conf{'antivirus_notify'} eq 'sender') {
+#	    #printf "do message, virus= $rc \n";
+#	    $list->send_file('your_infected_msg', $sender, $robot, {'virus_name' => $rc,
+#								    'recipient' => $listname.'@'.$host,
+#								    'lang' => $list->{'admin'}{'lang'}});
+#	}
+#	&do_log('notice', "Message for %s\@%s from %s ignored, virus %s found", $listname, $host, $sender, $rc);
+#	return undef;
+#    }
     
     ## Call scenarii : auth_method MD5 do not have any sense in send
     ## scenarii because auth is perfom by distribute or reject command.
@@ -1010,14 +1031,14 @@ sub DoMessage{
     my $action ;
     if ($is_signed->{'body'}) {
 	$action = &List::request_action ('send', 'smime',$robot,
-					 {'listname' => $name,
+					 {'listname' => $listname,
 					  'sender' => $sender,
-					  'msg' => $msg });
+					  'message' => $message });
     }else{
 	$action = &List::request_action ('send', 'smtp',$robot,
-					 {'listname' => $name,
+					 {'listname' => $listname,
 					  'sender' => $sender,
-					  'msg' => $msg });
+					  'message' => $message });
     }
 
     return undef
@@ -1025,37 +1046,39 @@ sub DoMessage{
 
     if ($action =~ /^do_it/) {
 	
-	my $numsmtp = $list->distribute_msg($msg, $bytes, $file, $encrypt);
+	my $numsmtp = $list->distribute_msg($message);
 
-	$msgid_table{$listname}{$messageid}++;
+	## Keep track of known message IDs...if any
+	$msgid_table{$listname}{$messageid}++
+	    if ($messageid);
 	
 	unless (defined($numsmtp)) {
-	    do_log('info','Unable to send message to list %s', $name);
+	    do_log('info','Unable to send message to list %s', $listname);
 	    return undef;
 	}
 
-	do_log('info', 'Message for %s from %s accepted (%d seconds, %d sessions), size=%d', $name, $sender, time - $start_time, $numsmtp, $bytes);
+	do_log('info', 'Message for %s from %s accepted (%d seconds, %d sessions), size=%d', $listname, $sender, time - $start_time, $numsmtp, $message->{'size'});
 	
 	## Everything went fine, return TRUE in order to remove the file from
 	## the queue.
 	return 1;
     }elsif($action =~ /^request_auth/){
     	my $key = $list->send_auth($message);
-	do_log('notice', 'Message for %s from %s kept for authentication with key %s', $name, $sender, $key);
+	do_log('notice', 'Message for %s from %s kept for authentication with key %s', $listname, $sender, $key);
 	return 1;
     }elsif($action =~ /^editorkey(\s?,\s?(quiet))?/){
 	my $key = $list->send_to_editor('md5',$message);
-	do_log('info', 'Key %s for list %s from %s sent to editors, %s', $key, $name, $sender, $file, $encrypt);
+	do_log('info', 'Key %s for list %s from %s sent to editors, %s', $key, $listname, $sender, $message->{'filename'});
 	$list->notify_sender($sender) unless ($2 eq 'quiet');
 	return 1;
     }elsif($action =~ /^editor(\s?,\s?(quiet))?/){
 	my $key = $list->send_to_editor('smtp', $message);
-	do_log('info', 'Message for %s from %s sent to editors', $name, $sender);
+	do_log('info', 'Message for %s from %s sent to editors', $listname, $sender);
 	$list->notify_sender($sender) unless ($2 eq 'quiet');
 	return 1;
     }elsif($action =~ /^reject(\(\'?(\w+)\'?\))?(\s?,\s?(quiet))?/) {
 	my $tpl = $2;
-	do_log('notice', 'Message for %s from %s rejected(%s) because sender not allowed', $name, $sender, $tpl);
+	do_log('notice', 'Message for %s from %s rejected(%s) because sender not allowed', $listname, $sender, $tpl);
 	unless ($4 eq 'quiet') {
 	    if ($tpl) {
 		$list->send_file($tpl, $sender, $robot, {});
@@ -1063,16 +1086,19 @@ sub DoMessage{
 		*SIZ  = smtp::smtpto(&Conf::get_robot_conf($robot, 'request'), \$sender);
 		print SIZ "From: " . sprintf (Msg(12, 4, 'SYMPA <%s>'), &Conf::get_robot_conf($robot, 'request')) . "\n";
 		printf SIZ "To: %s\n", $sender;
-		printf SIZ "Subject: " . Msg(4, 11, "Your message for list %s has been rejected")."\n", $name ;
+		printf SIZ "Subject: " . Msg(4, 11, "Your message for list %s has been rejected")."\n", $listname ;
 		printf SIZ "MIME-Version: %s\n", Msg(12, 1, '1.0');
 		printf SIZ "Content-Type: text/plain; charset=%s\n", Msg(12, 2, 'us-ascii');
 		printf SIZ "Content-Transfer-Encoding: %s\n\n", Msg(12, 3, '7bit');
-		printf SIZ Msg(4, 15, $msg::list_is_private), $name;
-		$msg->print(\*SIZ);
+		printf SIZ Msg(4, 15, $msg::list_is_private), $listname;
+		$message->{'msg'}->print(\*SIZ);
 		close(SIZ);
 	    }
 	}
 	return undef;
+    }else {
+	&do_log('err','Unknown action %s returned by the scenario', $action);
+	return undef;
     }
 }
 
@@ -1087,7 +1113,7 @@ sub DoCommand {
     my $hdr = $msg->head;
     
     ## Decode headers
-    $hdr->decode();
+    #$hdr->decode();
     
     my $from_field = $hdr->get('From');
     my $messageid = $hdr->get('Message-Id');
@@ -1103,7 +1129,10 @@ sub DoCommand {
 	do_log('notice', 'Found known Message-ID, ignoring command which would cause a loop');
 	return undef;
     }
-    $msgid_table{$robot}{$messageid}++;
+    
+    ## Keep track of known message IDs...if any
+    $msgid_table{$robot}{$messageid}++
+	if ($messageid);
 
     ## If X-Sympa-To = <listname>-<subscribe|unsubscribe> parse as a unique command
     if ($rcpt =~ /^(\S+)-(subscribe|unsubscribe)(\@(\S+))?$/o) {
@@ -1114,7 +1143,7 @@ sub DoCommand {
     
     ## Process the Subject of the message
     ## Search and process a command in the Subject field
-    my $subject_field = $hdr->get('Subject');
+    my $subject_field = &MIME::Words::decode_mimewords($hdr->get('Subject'));
     chomp $subject_field;
     $subject_field =~ s/\n//mg; ## multiline subjects
     $subject_field =~ s/^\s*(Re:)?\s*(.*)\s*$/$2/i;
@@ -1171,7 +1200,8 @@ sub DoCommand {
 	    }
 	    $i =~ s/^\s*>?\s*(.*)\s*$/$1/g;
 	    next if ($i =~ /^$/); ## skip empty lines
-	    
+	    next if ($i =~ /^\s*\#/) ;
+    
 	    # exception in the case of command expire
 	    if ($i =~ /^exp(ire)?\s/i){
 		$expire = $i;
@@ -1329,7 +1359,7 @@ sub ProcessExpire{
 }
 
 	    while ($user = $list->get_next_user()) {
-		$cpt_badboys++ if ($user->{'date'} < $limitday);
+		$cpt_badboys++ if ($user->{'update_date'} < $limitday);
 	    }
 
 	    ## Message to the owner who launched the expire command
@@ -1344,8 +1374,10 @@ sub ProcessExpire{
 		return undef;
 	    }
 
+	    if ($user->{'update_date'} < $limitday){print " $user->{'email'} ";$temp=1;}
+
 	    while ($user = $list->get_next_user()) {
-		next unless ($user->{'date'} < $limitday);
+		next unless ($user->{'update_date'} < $limitday);
 		print "," if ($temp == 1);
 		print " $user->{'email'} ";
 		$temp=1 if ($temp == 0);
@@ -1357,8 +1389,11 @@ sub ProcessExpire{
 	    unless ($user = $list->get_first_user()) {
 		return undef;
 	    }
+
+	    if ($user->{'update_date'} < $limitday){print "DEL $listname $user->{'email'}\n";}
+	    
 	    while ($user = $list->get_next_user()) {
-		next unless ($user->{'date'} < $limitday);
+		next unless ($user->{'update_date'} < $limitday);
 		print "DEL   $listname   $user->{'email'}\n";
 	    }
 	    ## Mail back the result.
