@@ -1,7 +1,7 @@
 #! --PERL--
 
 # task_manager.pl - This script runs as a daemon and processes periodical Sympa tasks
-# RCS Identication ; $Revision: 1.57.2.1 $ ; $Date: 2004/04/22 15:49:10 $ 
+# RCS Identication ; $Revision: 1.57.2.2 $ ; $Date: 2004/09/16 08:57:25 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -291,7 +291,9 @@ while (!$end) {
 		my $model_task_parameter = "$model".'_task';
 		
 		if ( $model eq 'sync_include') {
-		    next unless ($list->{'admin'}{'user_data_source'} eq 'include2');
+		    next unless (($list->{'admin'}{'user_data_source'} eq 'include2') &&
+				 $list->has_include_data_sources() &&
+				 ($list->{'admin'}{'status'} eq 'open'));
 		    
 		    create ($current_date, 'INIT', $model, 'ttl', 'list', \%data);
 
@@ -874,6 +876,7 @@ sub next_cmd {
 		error ($context->{'task_file'}, "List $list->{'name'} no more require sync_include task");
 		return undef;
 	    }
+
 	    $data{'list'}{'ttl'} = $list->{'admin'}{'ttl'};
 	    $model_choice = 'ttl';
 	}else {
@@ -1662,9 +1665,14 @@ sub sync_include {
 	return undef;                                                          
     }
  
+    if (! $list->has_include_data_sources() &&
+	(!$list->{'last_sync'} || ($list->{'last_sync'} > (stat("$list->{'dir'}/config"))[9]))) {
+	&do_log('notice', "List $list->{'name'} no more require sync_include task");
+	return undef;	
+    }    
 
     $list->sync_include();
-}
+    }
 
 ## Check if the provided filename matches a task
 ## Returns an array of its parts
