@@ -1,5 +1,5 @@
 # tools.pl - This module provides various tools for Sympa
-# RCS Identication ; $Revision: 1.130.2.3 $ ; $Date: 2004/06/03 15:03:38 $ 
+# RCS Identication ; $Revision: 1.130.2.7 $ ; $Date: 2005/01/27 10:02:26 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -32,7 +32,7 @@ use File::Find;
 use Digest::MD5;
 
 ## RCS identification.
-#my $id = '@(#)$Id: tools.pl,v 1.130.2.3 2004/06/03 15:03:38 olivier.salaun Exp $';
+#my $id = '@(#)$Id: tools.pl,v 1.130.2.7 2005/01/27 10:02:26 sympa-authors Exp $';
 
 ## global var to store a CipherSaber object 
 my $cipher;
@@ -97,7 +97,7 @@ sub checkcommand {
    ## Check for commands in the subject.
    my $subject = $msg->head->get('Subject');
    if ($subject) {
-       if ($Conf{'misaddressed_commands_regexp'} && ($subject =~ /^$Conf{'misaddressed_commands_regexp'}$/im)) {
+       if ($Conf{'misaddressed_commands_regexp'} && ($subject =~ /^$Conf{'misaddressed_commands_regexp'}\b/im)) {
 	   &rejectMessage($msg, $sender,$robot);
 	   return 1;
        }
@@ -106,7 +106,7 @@ sub checkcommand {
    return 0 if ($#{$msg->body} >= 5);  ## More than 5 lines in the text.
 
    foreach $i (@{$msg->body}) {
-       if ($Conf{'misaddressed_commands_regexp'} && ($i =~ /^$Conf{'misaddressed_commands_regexp'}$/im)) {
+       if ($Conf{'misaddressed_commands_regexp'} && ($i =~ /^$Conf{'misaddressed_commands_regexp'}\b/im)) {
 	   &rejectMessage($msg, $sender, $robot);
 	   return 1;
        }
@@ -839,28 +839,27 @@ sub as_singlepart {
     my ($msg, $preferred_type) = @_;
     my $done = 0;
     
-    # First, if the message has a type of multipart/alternative
-    # make this the main message so we can get at the sub parts
-    my @parts = $msg->parts();
-    foreach my $index (0..$#parts) {
-        if ($parts[$index]->effective_type() =~ /^multipart\/alternative/) {
-            ## Only keep the multipart/alternative part
-            $msg->parts([$parts[$index]]);
-            $msg->make_singlepart();
-            last;
-        }
-    }
-
-    # Now look for the preferred_type and if found, make this the main message
-    @parts = $msg->parts();
-    foreach my $index (0..$#parts) {
-	if ($parts[$index]->effective_type() =~ /^$preferred_type$/) {
-	    ## Only keep the first matching part
-	    $msg->parts([$parts[$index]]);
-	    $msg->make_singlepart();
-	    $done = 1;
-	    last;
+    if ($msg->effective_type() =~ /^multipart\/alternative/) {
+	my @parts = $msg->parts();
+	foreach my $index (0..$#parts) {
+	    if (($parts[$index]->effective_type() =~ /^$preferred_type$/) ||
+		(
+		 ($parts[$index]->effective_type() =~ /^multipart\/related$/) &&
+		 ($parts[$index]->parts(0)->effective_type() =~ /^$preferred_type$/))) {
+		## Only keep the first matching part
+		$msg->parts([$parts[$index]]);
+		$msg->make_singlepart();
+		$done = 1;
+		last;
+	    }
 	}
+    }elsif ($msg->effective_type() =~ /^multipart/) {
+	my @parts = $msg->parts();
+	foreach my $index (0..$#parts) {
+	    if ($parts[$index]->effective_type() =~ /^multipart\/alternative/) {
+		$done ||= &as_singlepart($parts[$index], $preferred_type);
+	    }
+	}    
     }
 
     return $done;
@@ -1555,7 +1554,7 @@ sub write_pid {
 sub get_message_id {
     my $robot = shift;
 
-    my $id = sprintf 'sympa.%d.%d.%d@%s', time, $$, int(rand(999)), $robot;
+    my $id = sprintf '<sympa.%d.%d.%d@%s>', time, $$, int(rand(999)), $robot;
 
     return $id;
 }
