@@ -1,7 +1,7 @@
 #!--PERL--
 
 # archived.pl - This script does the web archives building for Sympa
-# RCS Identication ; $Revision: 1.28.2.1 $ ; $Date: 2002/12/19 09:18:25 $ 
+# RCS Identication ; $Revision: 1.38.2.2 $ ; $Date: 2004/06/03 15:29:47 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -52,6 +52,8 @@ if ($main::options{'debug'}) {
     $main::options{'log_level'} = 2 unless ($main::options{'log_level'});
 }
 
+$main::options{'foreground'} = 1 if ($main::options{'debug'});
+
 $Version = '0.1';
 
 $wwsympa_conf = "--WWSCONFIG--";
@@ -112,6 +114,10 @@ $( = $) = (getgrnam('--GROUP--'))[2];
 $< = $> = (getpwnam('--USER--'))[2];
 
 
+## Required on FreeBSD to change ALL IDs(effective UID + real UID + saved UID)
+&POSIX::setuid((getpwnam('--USER--'))[2]);
+&POSIX::setgid((getgrnam('--GROUP--'))[2]);
+
 ## Sets the UMASK
 umask(oct($Conf{'umask'}));
 
@@ -120,6 +126,8 @@ unless ((-r $wwsconf->{'arc_path'}) && (-w $wwsconf->{'arc_path'})) {
     do_log('err', 'Unsufficient access to %s directory', $wwsconf->{'arc_path'});
 }
 
+&Language::LoadLang($Conf{'msgcat'});
+
 ## Change to list root
 unless (chdir($Conf{'home'})) {
     &message('chdir_error');
@@ -154,7 +162,7 @@ while (!$end) {
        fatal_err("Can't open dir %s: %m", $queue); ## No return.
    }
 
-   my @files =  (sort grep(!/^\.{1,2}$/, readdir DIR ));
+   my @files =  (grep(!/^\.{1,2}$/, readdir DIR ));
    closedir DIR;
 
    ## this sleep is important to be raisonably sure that sympa is not currently
@@ -192,7 +200,7 @@ while (!$end) {
 	   
 	   if ($file =~ /^(\d{4})-(\d{2})-(\d{2})-(\d{2})-(\d{2})-(\d{2})-(.*)$/) {
 	       ($yyyy, $mm, $dd, $hh, $min, $ss, $adrlist) = ($1, $2, $3, $4, $5, $6, $7);
-	   }elsif ($file =~ /^(.*)\.(\d+)\.(\d+)$/) {
+	   }elsif (($file =~ /^(.*)\.(\d+)\.(\d+)\.(\d+)$/) || ($file =~ /^(.*)\.(\d+)\.(\d+)$/)) {
 	       $adrlist = $1;
 	       my $date = $2;
 
@@ -279,26 +287,14 @@ sub rebuild {
 
     do_log('debug',"Rebuilding $adrlist archive ($2)");
 
-    my $mhonarc_ressources = &get_ressources ($adrlist) ; 
+    my $mhonarc_ressources = &tools::get_filename('etc','mhonarc-ressources',$list->{'domain'}, $list);
 
     if (($list->{'admin'}{'web_archive_spam_protection'} ne 'none') && ($list->{'admin'}{'web_archive_spam_protection'} ne 'cookie')) {
-	$ENV{'M2H_ADDRESSMODIFYCODE'} = 's|([\!\%\w\.\-+=/]+)@([\w\.\-]+)|[hidden_head]'.$1.'[hidden_at]'.$2.'[hidden_end]|g';
+	&set_hidden_mode();
+    }else {
+	&unset_hidden_mode();
     }
 
-#    if ($list->{'admin'}{'web_archive_spam_protection'} eq 'at') {
-#	$ENV{'M2H_ADDRESSMODIFYCODE'} = 's|([\!\%\w\.\-+=/]+)@([\w\.\-]+)|$1.'."' AT '".'.$2|ge';
-#    }elsif ($list->{'admin'}{'web_archive_spam_protection'} eq 'javascript'){
-#	my $javascript = '
-#<SCRIPT language=JavaScript>
-#<!--
-#document.write("<A HREF=" + "mail" + "to:" + "$1" + "@" + "$2" + "$1" + "@" + "$2" +"</A>") 
-#// --> </SCRIPT>';
-#	$javascript =~ s/</\\\</g;
-#	$javascript =~ s/>//g;
-#	
-#	$ENV{'M2H_ADDRESSMODIFYCODE'} = 's|([\!\%\w\.\-+=/]+)@([\w\.\-]+)|'.$javascript.'|ge';
-#	$ENV{'M2H_ADDRESSMODIFYCODE'} = 's|([\!\%\w\.\-+=/]+)@([\w\.\-]+)|'.$javascript.'|g';
-#    }
     do_log('notice','Rebuilding  $arc with M2H_ADDRESSMODIFYCODE : %s',$ENV{'M2H_ADDRESSMODIFYCODE'});
 
 
@@ -343,14 +339,18 @@ sub rebuild {
 sub mail2arc {
 
     my ($file, $listname, $hostname, $yyyy, $mm, $dd, $hh, $min, $ss) = @_;
-
-    do_log ('debug2',"mail2arc ($file, $listname, $hostname, $yyyy, $mm, $dd, $hh, $min, $ss)");
-
     my $arcpath = $wwsconf->{'arc_path'};
+    my $newfile;
     
 
     my $list = new List($listname);
 
+    if (($list->{'admin'}{'web_archive_spam_protection'} ne 'none') && ($list->{'admin'}{'web_archive_spam_protection'} ne 'cookie')) {
+	&set_hidden_mode();
+    }else {
+	&unset_hidden_mode();
+    }    
+
     do_log('debug',"mail2arc $file for $listname\@$hostname yyyy:$yyyy, mm:$mm dd:$dd hh:$hh min$min ss:$ss");
     #    chdir($wwsconf->{'arc_path'});
     
@@ -402,13 +402,24 @@ sub mail2arc {
     }
     
     ## copy the file in the arctxt and in "mhonarc -add"
-    opendir (DIR, "$arcpath/$listname\@$hostname/$yyyy-$mm/arctxt");
-    my @files = (sort { $a <=> $b;}  readdir(DIR)) ;
-    $files[$#files]+=1;
-    my $newfile = $files[$#files];
-#    my $newfile = $files[$#files]+=1;
+     if( -f "$arcpath/$listname\@$hostname/$yyyy-$mm/index" )
+     {
+	open(IDX,"<$arcpath/$listname\@$hostname/$yyyy-$mm/index") || fatal_err("couldn't read index for $listname");
+	$newfile = <IDX>;
+	chomp($newfile);
+	$newfile++;
+	close IDX;
+     }
+     else
+     {
+	do_log('debug',"indexing $listname archive");
+	opendir (DIR, "$arcpath/$listname\@$hostname/$yyyy-$mm/arctxt");
+	my @files = (sort { $a <=> $b;}  readdir(DIR)) ;
+	$files[$#files]+=1;
+	$newfile = $files[$#files];
+     }
     
-    my $mhonarc_ressources = &get_ressources ($listname . '@' . $hostname) ; 
+    my $mhonarc_ressources = &tools::get_filename('etc','mhonarc-ressources',$list->{'domain'}, $list);
     
     do_log ('debug',"calling $wwsconf->{'mhonarc'} for list $listname\@$hostname" ) ;
     my $cmd = "$wwsconf->{'mhonarc'} -add -rcfile $mhonarc_ressources -outdir $arcpath/$listname\@$hostname/$yyyy-$mm  -definevars \"listname='$listname' hostname=$hostname yyyy=$yyyy mois=$mm yyyymm=$yyyy-$mm wdir=$wwsconf->{'arc_path'} base=$Conf{'wwsympa_url'}/arc \" -umask $Conf{'umask'} < $queue/$file";
@@ -427,34 +438,26 @@ sub mail2arc {
     
     close ORIG;  
     close DEST;
+    &save_idx("$arcpath/$listname\@$hostname/$yyyy-$mm/index",$newfile);
 }
 
-sub get_ressources {
-    my $adrlist = shift;
-    my ($mhonarc_ressources, $list);  
+sub set_hidden_mode {
+    ## $ENV{'M2H_MODIFYBODYADDRESSES'}  positionner si le corps du message est pars
+    $ENV{'M2H_ADDRESSMODIFYCODE'} = 's|^([^@]+)@([^@]+)$|\[hidden_head\]$1\[hidden_at\]$2\[hidden_end\]|g';	
+}
 
-    if ($adrlist =~ /^([^@]*)\@[^@]*$/) {
-	$adrlist = $1;
-    }
-    unless ($list = new List ($adrlist)) {
-	do_log('err',"get_ressources : unable to load list $1, continue anyway");
-    }  
+sub unset_hidden_mode {
     
-    #$mhonarc_ressources = &tools::get_filename('etc', 'mhonarc-ressources', $robot, $list);
-    if (-r "$list->{'dir'}/mhonarc-ressources") {
-	$mhonarc_ressources =  "$list->{'dir'}/mhonarc-ressources" ;
-    }elsif (-r "$Conf{'etc'}/mhonarc-ressources"){
-        $mhonarc_ressources =  "$Conf{'etc'}/mhonarc-ressources" ;
-    }elsif (-r "--ETCBINDIR--/mhonarc-ressources"){
-        $mhonarc_ressources =  "--ETCBINDIR--/mhonarc-ressources" ;
-    }else {
-	do_log('err',"Cannot find any MhOnArc ressource file");
-	return undef;
-    }
-    return  $mhonarc_ressources;
+    ## Be carefull, the .mhonarc.db file keeps track of previous M2H_ADDRESSMODIFYCODE setup
+    $ENV{'M2H_ADDRESSMODIFYCODE'} = '';
 }
 
-
-
-
+sub save_idx {
+    my ($index,$lst) = @_;
+    
+    open(INDEXF,">$index") || fatal_err("couldn't overwrite index $index");
+    print INDEXF "$lst\n";
+    close INDEXF;
+    #   do_log('debug',"last arc entry for $index is $lst");
+}
 
