@@ -1,5 +1,5 @@
 # bounce-lib.pl - This module includes functions for analysing non-delivery reports
-# RCS Identication ; $Revision: 1.5 $ ; $Date: 2002/01/23 12:42:14 $ 
+# RCS Identication ; $Revision: 1.7 $ ; $Date: 2002/08/19 08:48:58 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -209,9 +209,13 @@ sub anabounce {
 
 	    if ($champ{'x-failed-recipients'} =~ /^\s*(\S+)$/) {
 		$info{$1}{error} = "";
+	    } elsif ($champ{'x-failed-recipients'} =~ /^\s*(\S+),/) {
+		for my $xfr (split (/\s*,\s*/, $champ{'x-failed-recipients'})) {
+		    $info{$xfr}{error} = "";
+		}
 	    }
 
-	}elsif (/^\s*-+ The following addresses (had permanent fatal errors|had transient non-fatal errors|have delivery notifications) -+/m) {
+	    }elsif (/^\s*-+ The following addresses (had permanent fatal errors|had transient non-fatal errors|have delivery notifications) -+/m) {
 	    
 	    my $adr;
 	    
