@@ -2,7 +2,7 @@
 
 # bounced.pl - This script runs as a daemon ; it does the incoming 
 # non-delivery reports analysis and storage
-# RCS Identication ; $Revision: 1.37 $ ; $Date: 2002/09/18 12:20:50 $ 
+# RCS Identication ; $Revision: 1.41.2.1 $ ; $Date: 2004/06/03 15:29:47 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -85,6 +85,9 @@ if ($main::options{'debug'}) {
     $main::options{'log_level'} = 2 unless ($main::options{'log_level'});
 }
 
+$main::options{'foreground'} = 1 if ($main::options{'debug'});
+
+
 my $wwsympa_conf = "--WWSCONFIG--";
 my $sympa_conf_file = '--CONFIG--';
 
@@ -140,10 +143,15 @@ do_openlog($wwsconf->{'log_facility'}, $Conf{'log_socket_type'}, 'bounced');
 $( = $) = (getgrnam('--GROUP--'))[2];
 $< = $> = (getpwnam('--USER--'))[2];
 
+## Required on FreeBSD to change ALL IDs(effective UID + real UID + saved UID)
+&POSIX::setuid((getpwnam('--USER--'))[2]);
+&POSIX::setgid((getgrnam('--GROUP--'))[2]);
 
 ## Sets the UMASK
 umask(oct($Conf{'umask'}));
 
+&Language::LoadLang($Conf{'msgcat'});
+
 ## Change to list root
 unless (chdir($Conf{'home'})) {
     &message('chdir_error');
@@ -176,7 +184,7 @@ while (!$end) {
 	fatal_err("Can't open dir %s: %m", $queue); ## No return.
     }
 
-    my @files =  (sort grep(!/^(\.{1,2}|T\..*)$/, readdir DIR ));
+    my @files =  (sort grep(!/^(\.{1,2}|T\..*|BAD\-.*)$/, readdir DIR ));
     closedir DIR;
     foreach my $file (@files) {
 
@@ -378,7 +386,8 @@ while (!$end) {
 	}
 	
 	unless (unlink("$queue/$file")) {
-	    do_log ('notice',"Could not remove $queue/$file ; $0 might NOT be running with the right UID\nRenaming file to $queue/BAD-$file.");
+	    do_log ('err',"Could not remove $queue/$file ; $0 might NOT be running with the right UID or file was not created with the right UID");
+	    &do_log('err',"Renaming file to $queue/BAD-$file.");
 	    rename "$queue/$file", "$queue/BAD-$file";
 	    last;
 	}
