@@ -1,5 +1,5 @@
 # wwslib.pm - This module includes functions used by wwsympa.fcgi
-# RCS Identication ; $Revision: 1.36 $ ; $Date: 2002/10/15 13:34:12 $ 
+# RCS Identication ; $Revision: 1.43 $ ; $Date: 2004/03/05 09:25:24 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -21,11 +21,17 @@
 
 
 package wwslib;
+use lib '--LIBDIR--';
 
 use Exporter;
 @ISA = ('Exporter');
 @EXPORT = ();
 
+use Log;
+use Conf;
+# use Net::SSLeay qw(&get_https);
+# use Net::SSLeay;
+
 ## Supported web languages
 @languages = ('fr','us','es','it','nl','cn','cz','de','hu','et','ro','fi');
 
@@ -131,7 +137,8 @@ sub load_config {
     my $file = pop;
 
     ## Old params
-    my %old_param = ('alias_manager' => 'No more used, using --SBINDIR--/alias_manager.pl');
+    my %old_param = ('alias_manager' => 'No more used, using --SBINDIR--/alias_manager.pl',
+		     'wws_path' => 'No more used');
 
     ## Valid params
     my %default_conf = (arc_path => '/home/httpd/html/arc',
@@ -147,11 +154,11 @@ sub load_config {
 			task_manager_pidfile => '--PIDDIR--/task_manager.pid',
 			title => 'Mailing Lists Service',
 			use_fast_cgi => 1,
-			wws_path => '--BINDIR--',
 			default_home => 'home',
 			log_facility => '',
 			robots => '',
 			password_case => 'insensitive',
+			htmlarea_url => '',
 			);
 
     my $conf = \%default_conf;
@@ -248,7 +255,7 @@ sub load_mime_types {
 sub get_email_from_cookie {
 #    &Log::do_log('debug', 'get_email_from_cookie');
     my $secret = shift;
-    my $email ;
+    my ($email, $auth) ;
 
     unless ($secret) {
 	&main::message('error in sympa configuration');
@@ -260,13 +267,14 @@ sub get_email_from_cookie {
 	&Log::do_log('info', ' ENV{HTTP_COOKIE} undefined, authentication failure');
     }
 
-    unless ( $email = &cookielib::check_cookie ($ENV{'HTTP_COOKIE'}, $secret)) {
+    ($email, $auth) = &cookielib::check_cookie ($ENV{'HTTP_COOKIE'}, $secret);
+    unless ( $email) {
 	&main::message('auth failed');
 	&Log::do_log('info', 'get_email_from_cookie: auth failed for user %s', $email);
 	return undef;
     }    
 
-    return $email;
+    return ($email, $auth);
 }
 
 sub new_passwd {
@@ -289,7 +297,8 @@ sub valid_email {
 
 # create a cipher
 sub ciphersaber_installed {
-    if (require (Crypt::CipherSaber)) {
+    if (eval "require Crypt::CipherSaber") {
+	require Crypt::CipherSaber;
 	return &Crypt::CipherSaber->new($Conf{'cookie'});
     }else{
 	return ('no_cipher');
@@ -361,6 +370,22 @@ sub init_passwd {
     return 1;
 }
 
+sub get_my_url {
+    
+		 
+    my $return_url;
+    
+    if ($ENV{SSL_PROTOCOL}) {
+	$return_url = 'https';
+    }else{
+	$return_url = 'http';	
+    }	     
+
+    $return_url .= '://'.$ENV{'HTTP_HOST'};
+    $return_url .= ':'.$ENV{'SERVER_PORT'} unless (($ENV{'SERVER_PORT'} eq '80')||($ENV{'SERVER_PORT'} eq '443'));
+    $return_url .= $ENV{'REQUEST_URI'};
+    return ($return_url);
+}
 
 1;
 
